@@ -11,8 +11,8 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '2.1'
-Build = '3'
+Version = '2.2'
+Build = '1'
 
 import sys
 import os
@@ -67,15 +67,15 @@ class clevenMainWindow(QtGui.QMainWindow):
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
 
        ##Connect Menu Buttons 
-       QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
-       QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.showAboutWindow)
+       QtCore.QObject.connect(self.ui.actionQuit,                    QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
+       QtCore.QObject.connect(self.ui.actionAbout,                   QtCore.SIGNAL('triggered()'), self.showAboutWindow)
        
        ##Connect Push Buttons
-       QtCore.QObject.connect(self.ui.pushButtonConfigureDrivers, QtCore.SIGNAL('clicked()'), self.showConfigureDriversDialog)
-       QtCore.QObject.connect(self.ui.pushButtonDecryptCaptured, QtCore.SIGNAL('clicked()'), self.showDecryptWindow)
-       QtCore.QObject.connect(self.ui.pushButtonShowKeys, QtCore.SIGNAL('clicked()'), self.showKeysWindow)
-       QtCore.QObject.connect(self.ui.pushButtonCapturePackets, QtCore.SIGNAL('clicked()'), self.showCaptureWindow)
-       QtCore.QObject.connect(self.ui.pushButtonDeleleCaptured, QtCore.SIGNAL('clicked()'), self.showDeleteWindow)
+       QtCore.QObject.connect(self.ui.pushButtonConfigureDrivers,    QtCore.SIGNAL('clicked()'), self.showConfigureDriversDialog)
+       QtCore.QObject.connect(self.ui.pushButtonDecryptCaptured,     QtCore.SIGNAL('clicked()'), self.showDecryptWindow)
+       QtCore.QObject.connect(self.ui.pushButtonShowKeys,            QtCore.SIGNAL('clicked()'), self.showKeysWindow)
+       QtCore.QObject.connect(self.ui.pushButtonCapturePackets,      QtCore.SIGNAL('clicked()'), self.showCaptureWindow)
+       QtCore.QObject.connect(self.ui.pushButtonDeleleCaptured,      QtCore.SIGNAL('clicked()'), self.showDeleteWindow)
 
        self.showStartupDialog()          ## (Un)comment for pop-up of the start-up dialog at start-up
        # self.showConfigureDriversDialog() ## (Un)comment for pop-up of the configuration dialog at start-up  
@@ -120,16 +120,16 @@ class clevenCapture(QtGui.QMainWindow):
        self.show()       
 
        ##Access Point
-       QtCore.QObject.connect(self.ui.scanButton, QtCore.SIGNAL('clicked()'), self.scanNetworks)
-       QtCore.QObject.connect(self.ui.wepRadio, QtCore.SIGNAL('clicked()'), self.displayNetworks)
-       QtCore.QObject.connect(self.ui.wpaRadio, QtCore.SIGNAL('clicked()'), self.displayNetworks)
-       QtCore.QObject.connect(self.ui.scanList, QtCore.SIGNAL('itemSelectionChanged()'), self.displayNetworkInformation)
+       QtCore.QObject.connect(self.ui.scanButton,  QtCore.SIGNAL('clicked()'), self.scanNetworks)
+       QtCore.QObject.connect(self.ui.wepRadio,    QtCore.SIGNAL('clicked()'), self.displayNetworks)
+       QtCore.QObject.connect(self.ui.wpaRadio,    QtCore.SIGNAL('clicked()'), self.displayNetworks)
+       QtCore.QObject.connect(self.ui.scanList,    QtCore.SIGNAL('itemSelectionChanged()'), self.displayNetworkInformation)
 
        ##Capture of packets
-       QtCore.QObject.connect(self.ui.captureButton, QtCore.SIGNAL('clicked()'), self.executeCapture)
-       QtCore.QObject.connect(self.ui.authenticateButton, QtCore.SIGNAL('clicked()'), self.executeAuthenticate)
+       QtCore.QObject.connect(self.ui.captureButton,        QtCore.SIGNAL('clicked()'), self.executeCapture)
+       QtCore.QObject.connect(self.ui.authenticateButton,   QtCore.SIGNAL('clicked()'), self.executeAuthenticate)
        QtCore.QObject.connect(self.ui.deauthenticateButton, QtCore.SIGNAL('clicked()'), self.executeDeauthenticate)
-       QtCore.QObject.connect(self.ui.injectionButton, QtCore.SIGNAL('clicked()'), self.executeInjection)
+       QtCore.QObject.connect(self.ui.injectionButton,      QtCore.SIGNAL('clicked()'), self.executeInjection)
 
        self.ui.captureButton.setEnabled(False)
        self.ui.injectionButton.setHidden(True)
@@ -200,7 +200,7 @@ class clevenCapture(QtGui.QMainWindow):
 
     def displayNetworkInformation(self): #FIXME: read wlan info directly and not from a file.
 
-       global essid, bssid, channel, encryption, essid_clean
+       global essid, bssid, channel, encryption, power, essid_clean
     
        if self.ui.scanList.currentRow() == -1:
           self.ui.textBrowser.clear()
@@ -210,20 +210,22 @@ class clevenCapture(QtGui.QMainWindow):
        essid = self.ui.scanList.currentItem().text()
        essidInfo = os.popen('sudo %s/%s readESSIDinfo %s \"%s\"' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
        
-       essid = essidInfo[0]
-       bssid = essidInfo[1]
-       channel = essidInfo[2]
+       essid      = essidInfo[0]
+       bssid      = essidInfo[1]
+       channel    = essidInfo[2]
        encryption = essidInfo[3]
-       essid = essid.lstrip(" ").rstrip(" ")
-       bssid = bssid.strip()
-       channel = channel.strip()
+       power      = essidInfo[4]
+
+       essid      = essid.lstrip(" ").rstrip(" ")
+       bssid      = bssid.strip()
+       channel    = channel.strip()
        encryption = encryption.strip()
+       power      = power.strip()
        
        self.ui.textBrowser.clear()
        self.ui.textBrowser.append('Name: ' + essid)
        self.ui.textBrowser.append('MAC: ' + bssid)
-       self.ui.textBrowser.append('Ch: ' + channel + ' Security: ' + encryption)
-  
+       self.ui.textBrowser.append('Ch: ' + channel + ', Priv.: ' + encryption + ', Pw: ' + power + 'dBm')
   
        essid_clean = essid
        character_list = [' ', '(', ')', '!', '$', '%', '^', '&', '*', '-', '+', '=', '#', '@', ';', ':', '?', '/', '>', '<'] 
